<<<<<<< .mine
/*
 *   ORXONOX - the hottest 3D action shooter ever to exist
 *                    > www.orxonox.net <
 *
 *
 *   License notice:
 *
 *   This program is free software; you can redistribute it and/or
 *   modify it under the terms of the GNU General Public License
 *   as published by the Free Software Foundation; either version 2
 *   of the License, or (at your option) any later version.
 *
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public License
 *   along with this program; if not, write to the Free Software
 *   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 *
 *   Author:
 *      Cyrill Burgener
 *   Co-authors:
 *      ...
 *
 */

/**
    @file Hover.cc
    @brief Implementation of the Hover class.
*/

#include "Hover.h"
#include "HoverShip.h"
#include "core/CoreIncludes.h"

namespace orxonox
{
    RegisterUnloadableClass(Hover);

    Hover::Hover(Context* context) : Deathmatch(context)
    {
        RegisterObject(Hover);

        bEndGame = false;
        lives = 1;
        level = 1;
        point = 0;
        bShowLevel = false;
        multiplier = 1;
        b_combo = false;
        counter = 5000;
        pattern = 1;
        lastPosition = 0;
        // spawn enemy every 3.5 seconds
        //enemySpawnTimer.setTimer(3.5f, true, createExecutor(createFunctor(&Hover::spawnEnemy, this)));
        comboTimer.setTimer(3.0f, true, createExecutor(createFunctor(&Hover::comboControll, this)));
        this->numberOfBots_ = 0; //sets number of default bots temporarly to 0
        this->center_ = 0;

        this->setHUDTemplate("HoverHUD");
    }

    void Hover::levelUp()
    {
        level++;
        if (getPlayer() != NULL)
        {
            for (int i = 0; i < 7; i++)
            {
                BigExplosion* chunk = new BigExplosion(this->center_->getContext());
                chunk->setPosition(Vector3(600, 0, 100.f * i - 300));
                chunk->setVelocity(Vector3(1000, 0, 0));  //player->getVelocity()
                chunk->setScale(20);
            }
        }
        addPoints(multiplier * 42);
        multiplier *= 2;
        toggleShowLevel();
        showLevelTimer.setTimer(1.0f, false, createExecutor(createFunctor(&Hover::toggleShowLevel, this)));
    }

    void Hover::tick(float dt)
    {
        if (getPlayer() != NULL)
        {
            currentPosition = getPlayer()->getWorldPosition().x;
            counter = counter + (currentPosition - lastPosition);
            lastPosition = currentPosition;
            point = (int) currentPosition;
            getPlayer()->speed = 830.0f - (point / 1000);

            for(unsigned int i=0; i < cubeList.size();i++)
            {
                if(cubeList.at(i)->getPosition().x < currentPosition-3000)
                {
                    cubeList.at(i)->destroy();
                    cubeList.erase(cubeList.begin()+i);
                }
            }

            if(counter >= 3000)
            {
                counter = 0;
                for(int i = 0; i<6; i++)
                {
                    HoverCube* cube = new HoverCube(this->center_->getContext());
                    cubeList.push_back(cube);
                    switch(pattern)
                    {
                    case 1: cube->addTemplate("HoverCube01");
                    break;
                    case 2: cube->addTemplate("HoverCube02");
                    break;

                    }

                    cube->setPosition(getPlayer()->getWorldPosition() + Vector3(5000.0f, 0.0f, -3600.0f + (i*1200)));
                    //stEntity->setScale3D(50,50,50);
                }


                pattern %= 2;
                pattern ++;

            }

        }
        SUPER(Hover, tick, dt);
    }

    HoverShip* Hover::getPlayer()
    {
        if (player == NULL)
        {
            for (ObjectList<HoverShip>::iterator it = ObjectList<HoverShip>::begin(); it != ObjectList<HoverShip>::end(); ++it)
            {
                player = *it;
            }
        }
        return player;
    }

    void Hover::costLife()
    {
        //endGameTimer.setTimer(8.0f, false, createExecutor(createFunctor(&Hover::end, this)));
        lives = 0;
    };

    void Hover::comboControll()
    {
        if (b_combo)
            multiplier++;
        // if no combo was performed before, reset multiplier
        else
            multiplier = 1;
        b_combo = false;
    }

    void Hover::start()
    {
        orxout() << "start" << endl;
        for(unsigned int i=0; i< cubeList.size();i++)
        {
            cubeList.at(i)->destroy();
            cubeList.erase(cubeList.begin()+i);

        }
        cubeList.clear();
        // Set variable to temporarily force the player to spawn.
        this->bForceSpawn_ = false;

        if (this->center_ == NULL)  // abandon mission!
        {
            orxout(internal_error) << "Hover: No Centerpoint specified." << endl;
            GSLevel::startMainMenu();
            return;
        }
        // Call start for the parent class.
        Deathmatch::start();
    }

    void Hover::playerPreSpawn(PlayerInfo* player)
    {
        if(lives <= 0)
        {
            this->end();
        }

        // Reset all the cubes
        /*
        orxout() << "prespawn" << endl;
        for(int i=0; i< cubeList.size();i++)
        {
            cubeList.at(i)->destroy();
            cubeList.erase(cubeList.begin()+i);
        }
        cubeList.clear();
        lives = 1;
        point = 0;
        lastPosition = 0;
        */
    }

    void Hover::addPoints(int numPoints)
    {
        if (!bEndGame)
        {
            point += numPoints * multiplier;
            b_combo = true;
        }
    }

    void Hover::end()
    {
        // DON'T CALL THIS!
        //      Deathmatch::end();
        // It will misteriously crash the game!
        // Instead startMainMenu, this won't crash.
        GSLevel::startMainMenu();
    }
}
=======
/*
 *   ORXONOX - the hottest 3D action shooter ever to exist
 *                    > www.orxonox.net <
 *
 *
 *   License notice:
 *
 *   This program is free software; you can redistribute it and/or
 *   modify it under the terms of the GNU General Public License
 *   as published by the Free Software Foundation; either version 2
 *   of the License, or (at your option) any later version.
 *
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public License
 *   along with this program; if not, write to the Free Software
 *   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 *
 *   Author:
 *      Florian Zinggeler
 *   Co-authors:
 *      ...
 *
 */

/**
    @file Hover.cc
    @brief Implementation of the Hover class.
*/

#include "Hover.h"
#include "HoverShip.h" // Necessary for getPlayer function. Do NOT include this in Header!
#include "core/CoreIncludes.h"

namespace orxonox
{
    RegisterUnloadableClass(Hover);

    Hover::Hover(Context* context) : GameType(context)
    {
        RegisterObject(Hover);

        //this->setHUDTemplate("HoverHUD");
    }



    void Hover::tick(float dt)
    {

        SUPER(Hover, tick, dt);
    }

    

    void Hover::start()
    {

        // Call start for the parent class.
        GameType::start();
    }


    void Hover::end()
    {
        // DON'T CALL THIS!
        //      Deathmatch::end();
        // It will misteriously crash the game!
        // Instead startMainMenu, this won't crash.
        GSLevel::startMainMenu();
    }
}
>>>>>>> .r10658
